@@ -87,33 +87,22 @@ class ImageRecognition(object):
         
         with tf.variable_scope('resnet_v2_152'):
             depth = out.get_shape().as_list()[-1]
+            out = new_fc_layer(out, 
+                                num_inputs = depth, 
+                                num_outputs = len(self.classes), 
+                                name = 'fc1', 
+                                dropout_val= 1 - dropout_rate, 
+                                activation="NONE",
+                                lrelu_alpha=0.2, 
+                                data_type=tf.float32,
+                                is_training=is_training,
+                                use_bias=False)
             
             if self.classification_by_regression: 
-                out = new_fc_layer(out, 
-                                num_inputs = depth, 
-                                num_outputs = 1, 
-                                name = 'fc1', 
-                                dropout_val= 1 - dropout_rate, 
-                                activation="NONE",
-                                lrelu_alpha=0.2, 
-                                data_type=tf.float32,
-                                is_training=is_training,
-                                use_bias=False)
                 out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-                out = tf.concat([out, 1.0 - out], 1)
+                #out[:, 1] = 1.0 - out[:, 0]
 
             else: 
-                out = new_fc_layer(out, 
-                                num_inputs = depth, 
-                                num_outputs = 2, 
-                                name = 'fc1', 
-                                dropout_val= 1 - dropout_rate, 
-                                activation="NONE",
-                                lrelu_alpha=0.2, 
-                                data_type=tf.float32,
-                                is_training=is_training,
-                                use_bias=False)
-
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -183,24 +172,7 @@ class ImageRecognition(object):
             
             depth = out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
-            
-            if self.classification_by_regression:
-                out = new_fc_layer(out, 
-                                num_inputs = depth, 
-                                num_outputs = 1, 
-                                name = 'fc1', 
-                                dropout_val=1, 
-                                activation="NONE",
-                                lrelu_alpha=0.2, 
-                                data_type=tf.float32,
-                                is_training=is_training,
-                                use_bias=False)
-
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-                out = tf.concat([out, 1.0 - out], 1)
-            
-            else: 
-                out = new_fc_layer(out, 
+            out = new_fc_layer(out, 
                                 num_inputs = depth, 
                                 num_outputs = len(self.classes), 
                                 name = 'fc1', 
@@ -211,6 +183,12 @@ class ImageRecognition(object):
                                 is_training=is_training,
                                 use_bias=False)
 
+            
+            if self.classification_by_regression:
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                #out[:, 1] = 1.0 - out[:, 0]
+            
+            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -264,24 +242,7 @@ class ImageRecognition(object):
             
             depth =  out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
-
-            if self.classification_by_regression:
-                out = new_fc_layer(out, 
-                                    num_inputs = depth, 
-                                    num_outputs = 1, 
-                                    name = 'fc1', 
-                                    dropout_val=1 - dropout_rate, 
-                                    activation="NONE",
-                                    lrelu_alpha=0.2, 
-                                    data_type=tf.float32,
-                                    is_training=is_training,
-                                    use_bias=False)
-
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-                out = tf.concat([out, 1.0 - out], 1)
-
-            else: 
-                out = new_fc_layer(out, 
+            out = new_fc_layer(out, 
                                     num_inputs = depth, 
                                     num_outputs = len(self.classes), 
                                     name = 'fc1', 
@@ -292,6 +253,11 @@ class ImageRecognition(object):
                                     is_training=is_training,
                                     use_bias=False)
 
+            if self.classification_by_regression:
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                #out[:, 1] = 1.0 - out[:, 0]
+
+            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
